@@ -3,7 +3,7 @@ match_lengths <- function(x, y) {
   n.y <- length(y)
   n.max <- max(n.x, n.y)
   n.min <- min(n.x, n.y)
-  if (n.max %% n.min != 0L){
+  if (n.max %% n.min != 0L) {
     stop("longer object length is not a multiple of shorter object length")
   } else {
     if (n.x < n.y) {
@@ -15,7 +15,7 @@ match_lengths <- function(x, y) {
   list(x, y)
 }
 
-recognize <- function(x){
+recognize <- function(x) {
   recognized <- c("POSIXt", "POSIXlt", "POSIXct", "yearmon", "yearqtr", "Date")
 
   if (all(class(x) %in% recognized))
@@ -49,7 +49,7 @@ standardise_difftime_names <- function(x) {
 standardise_period_names <- function(x) {
   dates <- c("second", "minute", "hour", "day", "week", "month", "year",
              ## these ones are used for rounding only
-             "bimonth", "quarter", "halfyear")
+             "bimonth", "quarter", "halfyear", "season")
   y <- gsub("(.)s$", "\\1", x)
   y <- substr(y, 1, 3)
   res <- dates[pmatch(y, dates)]
@@ -61,7 +61,7 @@ standardise_period_names <- function(x) {
 }
 
 standardise_lt_names <- function(x) {
-  if(length(x) == 0L)
+  if (length(x) == 0L)
     stop("No unit names supplied.")
   dates <- c("sec", "min", "hour", "day", "mday", "wday", "yday", "mon", "year", "tz")
   y <- gsub("(.)s$", "\\1", x)
@@ -74,7 +74,7 @@ standardise_lt_names <- function(x) {
   res
 }
 
-## return list(n=nr_untis,  unti="unit_name")
+## return list(n=nr_units, unit="unit_name")
 parse_period_unit <- function(unit) {
 
   if (length(unit) > 1) {
@@ -82,30 +82,33 @@ parse_period_unit <- function(unit) {
     unit <- unit[[1]]
   }
 
-  p <- .Call("c_parse_period", as.character(unit))
+  p <- .Call(C_parse_period, as.character(unit))
 
   if (!is.na(p[[1]])) {
 
     period_units <- c("second", "minute", "hour", "day", "week", "month", "year")
 
     wp <- which(p > 0)
-    if(length(wp) > 1){
-      stop("Multi unit periods are not yet supported")
+    if (length(wp) > 1) {
+      ## Fractional units are actually supported but only when it leads to one
+      ## final unit.
+      stop("Cannot't parse heterogenuous or fractional units larger than one minute.")
     }
 
     list(n = p[wp], unit = period_units[wp])
 
   } else {
+    ## this part is for backward compatibility and allows for bimonth, halfyear
+    ## and quarter
 
-    ## this is for backward compatibility and allows for bimonth, halfyear and quarter
     m <- regexpr(" *(?<n>[0-9.,]+)? *(?<unit>[^ \t\n]+)", unit[[1]], perl = T)
-    if(m > 0){
+    if (m > 0) {
       ## should always match
       nms <- attr(m, "capture.names")
       nms <- nms[nzchar(nms)]
       start <- attr(m, "capture.start")
       end <- start + attr(m, "capture.length") - 1L
-      n <- if(end[[1]] >= start[[1]]){
+      n <- if (end[[1]] >= start[[1]]) {
              as.integer(str_sub(unit, start[[1]], end[[1]]))
            } else {
              1
@@ -119,8 +122,14 @@ parse_period_unit <- function(unit) {
   }
 }
 
-undefined_arithmetic <- function(e1, e2){
+undefined_arithmetic <- function(e1, e2) {
   msg <- sprintf("Arithmetic operators undefined for '%s' and '%s' classes:
   convert one to numeric or a matching time-span class.", class(e1), class(e2))
   stop(msg)
 }
+
+date_to_posix <- function(date, tz = "UTC") {
+  utc <- .POSIXct(unclass(date) * 86400, tz = "UTC")
+  if (tz == "UTC") utc
+  else force_tz(utc, tz)
+}
