@@ -1,4 +1,4 @@
-context("addition operations")
+context("Addition operations")
 
 test_that("addition handles daylight savings time", {
   x <- as.POSIXct("2010-03-14 00:00:00", tz = "America/New_York")
@@ -18,7 +18,7 @@ test_that("subtraction handles daylight savings time", {
   expect_that(x - ddays(1), equals(y))
 })
 
-test_that("addition works as expected for instants",{
+test_that("addition works as expected for instants", {
 
   x <- as.POSIXct("2008-01-01 00:00:00", tz = "UTC")
   y <- as.POSIXlt("2008-01-01 00:00:00", tz = "UTC")
@@ -42,7 +42,7 @@ test_that("addition works as expected for instants",{
   expect_error(z + int)
 })
 
-test_that("addition with instants returns correct class",{
+test_that("addition with instants returns correct class", {
   x <- as.POSIXct("2008-01-02 00:00:00", tz = "UTC")
   y <- as.POSIXlt("2008-01-02 00:00:00", tz = "UTC")
   z <- as.Date("2008-01-01")
@@ -57,7 +57,7 @@ test_that("addition with instants returns correct class",{
 })
 
 
-test_that("addition works as expected for periods",{
+test_that("addition works as expected for periods", {
   time1 <- as.POSIXct("2008-01-02 00:00:00", tz = "UTC")
   time2 <- as.POSIXct("2009-08-03 00:00:00", tz = "UTC")
   int <- interval(time1, time2)
@@ -71,14 +71,14 @@ test_that("addition works as expected for periods",{
   expect_that(years(1) + as.POSIXlt("2008-01-01 00:00:00", tz = "UTC"),
     equals(as.POSIXlt("2009-01-01 00:00:00", tz = "UTC")))
 
-  expect_that(years(1) + minutes(3),equals(period(minutes = 3,
+  expect_that(years(1) + minutes(3), equals(period(minutes = 3,
     years = 1)))
 
   expect_error(years(1) + dyears(1))
   expect_error(years(1) + int)
 })
 
-test_that("addition with periods returns correct class",{
+test_that("addition with periods returns correct class", {
 
   expect_is(years(1) + 1, "Period")
 
@@ -86,13 +86,13 @@ test_that("addition with periods returns correct class",{
     "2008-01-01 00:00:00", tz = "UTC"), "POSIXt")
 
   expect_is(years(1) + as.POSIXlt(
-    "2008-01-01 00:00:00", tz = "UTC"),"POSIXlt")
+    "2008-01-01 00:00:00", tz = "UTC"), "POSIXlt")
 
   expect_is(years(1) + minutes(3), "Period")
 })
 
 
-test_that("addition works as expected for durations",{
+test_that("addition works as expected for durations", {
 
   x <- as.POSIXct("2008-01-01 00:00:00", tz = "UTC")
   y <- as.POSIXct("2008-12-31 00:00:00", tz = "UTC")
@@ -107,7 +107,7 @@ test_that("addition works as expected for durations",{
   expect_error(dyears(1) + int)
 })
 
-test_that("addition with durations returns correct class",{
+test_that("addition with durations returns correct class", {
   ct <- as.POSIXct("2008-01-01 00:00:00", tz = "UTC")
   lt <- as.POSIXlt("2008-01-01 00:00:00", tz = "UTC")
 
@@ -117,7 +117,7 @@ test_that("addition with durations returns correct class",{
   expect_that(dyears(1) + dyears(1), is_a("Duration"))
 })
 
-test_that("addition works as expected for intervals",{
+test_that("addition works as expected for intervals", {
   time1 <- as.POSIXct("2008-08-03 13:01:59", tz = "UTC")
   time2 <- as.POSIXct("2009-08-03 13:01:59", tz = "UTC")
   time3 <- as.POSIXct("2008-01-01 00:00:00", tz = "UTC")
@@ -137,18 +137,18 @@ test_that("addition works as expected for intervals",{
   expect_error(int + int3)
 })
 
-
+
 #### Vectors
 
-test_that("adding vectors works as expected for instants",{
+test_that("adding vectors works as expected for instants", {
   x <- as.POSIXct(c("2008-01-01 00:00:00", "2009-01-01 00:00:00"),
-  	tz = "UTC")
+        tz = "UTC")
   y <- as.POSIXlt(c("2008-01-01 00:00:00",
     "2009-01-01 00:00:00"), tz = "UTC")
   z <- c(as.Date("2008-01-01"), as.Date("2008-01-10"))
 
   expect_that(x + years(1), equals(as.POSIXct(c(
-    "2009-01-01 00:00:00","2010-01-01 00:00:00"), tz =
+    "2009-01-01 00:00:00", "2010-01-01 00:00:00"), tz =
     "UTC")))
   expect_that(y + years(1), equals(as.POSIXlt(c(
     "2009-01-01 00:00:00", "2010-01-01 00:00:00"),
@@ -175,10 +175,10 @@ test_that("adding vectors works as expected for instants",{
   expect_error(z + int)
 })
 
-test_that("adding vectors works as expected for periods",{
+test_that("adding vectors works as expected for periods", {
 
   expect_that(years(1:2) + 1, equals(period(seconds = 1,
-    years = c(1,2))))
+    years = c(1, 2))))
 
   expect_that(years(1:2) + as.POSIXct("2008-01-01 00:00:00", tz = "UTC"),
     equals(as.POSIXct(c("2009-01-01 00:00:00",
@@ -201,7 +201,7 @@ test_that("adding vectors works as expected for periods",{
   expect_error(years(1:2) + int)
 })
 
-test_that("adding vectors works as expected for durations",{
+test_that("adding vectors works as expected for durations", {
   w <- as.POSIXct("2007-01-01 00:00:00", tz = "UTC")
   x <- as.POSIXct("2008-01-01 00:00:00", tz = "UTC")
   y <- as.POSIXct(c("2008-01-01 00:00:00", "2008-12-31 00:00:00"), tz = "UTC")
@@ -221,7 +221,7 @@ test_that("adding vectors works as expected for durations",{
 
 })
 
-test_that("adding vectors works as expected for intervals",{
+test_that("adding vectors works as expected for intervals", {
   time1 <- as.POSIXct("2008-08-03 00:00:00", tz = "UTC")
   time2 <- as.POSIXct("2009-08-03 00:00:00", tz = "UTC")
   time3 <- as.POSIXct("2010-08-03 00:00:00", tz = "UTC")
@@ -236,23 +236,22 @@ test_that("adding vectors works as expected for intervals",{
 
 })
 
-test_that("%m+% correctly adds months without rollover",{
+test_that("%m+% correctly adds months without rollover", {
   jan <- ymd_hms("2010-01-31 03:04:05")
   ends <- ymd_hms(c("2010-02-28 03:04:05", "2010-03-31 03:04:05", "2010-04-30 03:04:05"))
 
   expect_equal(jan %m+% months(1:3), ends)
 })
 
-test_that("%m+% correctly adds years without rollover",{
+test_that("%m+% correctly adds years without rollover", {
   leap <- ymd("2012-02-29")
   next1 <- ymd("2013-02-28")
   next2 <- ymd("2013-03-29")
-
   expect_equal(leap %m+% years(1), next1)
   expect_equal(leap %m+% period(years = 1, months = 1), next2)
 })
 
-test_that("%m+% correctly adds years, months, days and HMS (#286)",{
+test_that("%m+% correctly adds years, months, days and HMS (#286)", {
   date <- ymd("2012-02-29")
   per_all <- period(years = 1, months = 1, days = 2, hours = 1, minutes = 20, seconds = 30)
   per_major <- period(years = 1, months = 1)
@@ -268,14 +267,14 @@ test_that("%m+% correctly adds years, months, days and HMS (#286)",{
                date %m+% per_major + per_minor)
 })
 
-test_that("%m+% correctly adds negative months without rollover",{
+test_that("%m+% correctly adds negative months without rollover", {
   may <- ymd_hms("2010-05-31 03:04:05")
   ends <- ymd_hms(c("2010-04-30 03:04:05", "2010-03-31 03:04:05", "2010-02-28 03:04:05"))
 
   expect_equal(may %m+% -months(1:3), ends)
 })
 
-test_that("%m+% correctly adds negative years without rollover",{
+test_that("%m+% correctly adds negative years without rollover", {
   leap <- ymd("2012-02-29")
   next1 <- ymd("2011-02-28")
   next2 <- ymd("2011-01-29")
@@ -297,13 +296,13 @@ test_that("addition with period months and years returns NA when appropriate", {
                "2013-05-31", NA, "2013-07-31",
                "2013-08-31", NA, "2013-10-31", NA,
                "2013-12-31"), tz = "America/Chicago")
-  yrs <- ymd(c("2012-02-29", NA, NA, NA,"2016-02-29"), tz = "America/Chicago")
+  yrs <- ymd(c("2012-02-29", NA, NA, NA, "2016-02-29"), tz = "America/Chicago")
 
   mos2 <- ymd(c("2013-01-31", "2012-12-31", NA,
                "2012-10-31", NA, "2012-08-31",
                "2012-07-31", NA, "2012-05-31", NA,
                "2012-03-31", NA), tz = "America/Chicago")
-  yrs2 <- ymd(c("2012-02-29", NA, NA, NA,"2008-02-29"), tz = "America/Chicago")
+  yrs2 <- ymd(c("2012-02-29", NA, NA, NA, "2008-02-29"), tz = "America/Chicago")
 
 
 
@@ -316,3 +315,26 @@ test_that("addition with period months and years returns NA when appropriate", {
   expect_equal(leap - years(0:4), yrs2)
 
 })
+
+test_that("addition with durations containing NA", {
+
+  dt <- ymd(20161018)
+  dt_1 <- ymd(20161019)
+
+  dd_1na  <- ddays(c(1, NA))
+  dd_na1  <- ddays(c(NA, 1))
+  dd_nana <- ddays(c(NA, NA))
+
+  ans_1na  <- add_duration_to_date(dd_1na, dt)
+  ans_na1  <- add_duration_to_date(dd_na1, dt)
+  ans_nana <- add_duration_to_date(dd_nana, dt)
+
+  expect_is(ans_1na, "Date")
+  expect_is(ans_na1, "Date")
+  expect_is(ans_nana, "Date")
+
+  expect_equal(ans_1na, c(dt_1, NA))
+  expect_equal(ans_na1, rev(c(dt_1, NA)))
+  expect_equal(ans_nana, as.Date(c(NA, NA)))
+
+})
